+--------------------------------+
| layout: page                   |
+--------------------------------+
| title: ArrayType (llvm.core)   |
+--------------------------------+

llvm.core.ArrayType
===================

Base Class
----------

-  `llvm.core.Type <llvm.core.Type.html>`_

Properties
----------

``element``
~~~~~~~~~~~

[read-only]

A ``Type`` object representing the type of the element of the array.

``count``
~~~~~~~~~

[read-only]

The number of elements in the array.
